Proxy error types
This module defines all error types for the proxy crate.
Enums
- Proxy
Error - Errors that can occur in the proxy
Type Aliases
- Result
- Result type alias for proxy operations
Proxy error types
This module defines all error types for the proxy crate.