HTTP server implementation
This module provides the HTTP/HTTPS server for the proxy.
Uses ServiceRegistry for route resolution instead of the legacy Router.
Structs
- Proxy
Server - The proxy server
HTTP server implementation
This module provides the HTTP/HTTPS server for the proxy.
Uses ServiceRegistry for route resolution instead of the legacy Router.