pub struct ReverseProxyService { /* private fields */ }Expand description
The reverse proxy service
Implementations
Sourceimpl ReverseProxyService
impl ReverseProxyService
Sourcepub fn new(
registry: Arc<ServiceRegistry>,
load_balancer: Arc<LoadBalancer>,
config: Arc<ProxyConfig>,
) -> Self
pub fn new( registry: Arc<ServiceRegistry>, load_balancer: Arc<LoadBalancer>, config: Arc<ProxyConfig>, ) -> Self
Create a new reverse proxy service
Sourcepub fn with_remote_addr(self, addr: SocketAddr) -> Self
pub fn with_remote_addr(self, addr: SocketAddr) -> Self
Set the remote client address for this request
Sourcepub fn with_trusted_proxies(self, trusted: Arc<TrustedProxyList>) -> Self
pub fn with_trusted_proxies(self, trusted: Arc<TrustedProxyList>) -> Self
Override the trusted-proxy list (default: localhost_only).
Peers in this list are believed when they set CF-Connecting-IP or
X-Forwarded-For headers identifying the real client IP.
Sourcepub fn with_cert_manager(self, cm: Arc<CertManager>) -> Self
pub fn with_cert_manager(self, cm: Arc<CertManager>) -> Self
Set the certificate manager for ACME challenge interception
Sourcepub fn with_network_policy_checker(self, checker: NetworkPolicyChecker) -> Self
pub fn with_network_policy_checker(self, checker: NetworkPolicyChecker) -> Self
Set the network policy checker for access control enforcement
Sourcepub fn error_response(error: &ProxyError) -> Response<BoxBody>
pub fn error_response(error: &ProxyError) -> Response<BoxBody>
Create an error response
Panics
Panics if building a valid HTTP response with a JSON body fails, which should never occur with well-formed status codes.