pub fn load_certs(path: &str) -> Result<Vec<CertificateDer<'static>>>
Load certificates from a PEM file
Returns an error if the file cannot be opened, the PEM cannot be parsed, or no certificates are found.