load_private_key

Function load_private_key 

pub fn load_private_key(path: &str) -> Result<PrivateKeyDer<'static>>
Load a private key from a PEM file

Errors

Returns an error if the file cannot be opened, the PEM cannot be parsed, or no private key is found.