proxy_tunnel

Function proxy_tunnel 

pub async fn proxy_tunnel<C, S>(client: C, server: S) -> Result<()>
Proxy a tunnel connection between two upgraded connections

This function performs bidirectional copying between the client and server connections after an upgrade.

Errors

Returns an error if the bidirectional copy fails with a non-reset IO error.