proxy_upgrade

Function proxy_upgrade 

pub async fn proxy_upgrade(
    client_upgrade: OnUpgrade,
    server_upgrade: OnUpgrade,
) -> Result<()>
Handle upgrade with explicit upgrade futures

This is a higher-level function that takes OnUpgrade futures from hyper and handles the bidirectional copying between them.

Errors

Returns an error if either upgrade fails or if the bidirectional tunnel encounters a fatal IO error.