pub struct TcpStreamService { /* private fields */ }Expand description
TCP stream proxy service
Listens on a port and proxies TCP connections to registered backends using round-robin load balancing.
Implementations
Sourceimpl TcpStreamService
impl TcpStreamService
Sourcepub fn new(registry: Arc<StreamRegistry>, listen_port: u16) -> Self
pub fn new(registry: Arc<StreamRegistry>, listen_port: u16) -> Self
Create a new TCP stream service
Sourcepub fn registry(&self) -> &Arc<StreamRegistry>
pub fn registry(&self) -> &Arc<StreamRegistry>
Get a reference to the registry
Sourcepub async fn serve(self: Arc<Self>, listener: TcpListener)
pub async fn serve(self: Arc<Self>, listener: TcpListener)
Run a standalone TCP accept loop on the given listener.
For each accepted connection, resolves a backend from the registry and spawns a task to perform bidirectional tunneling. This method runs indefinitely until the listener encounters a fatal error.